==> mo-js-0.265.9.tgz: package/readme.md <==
# mo · js [![Build Status](https://travis-ci.org/legomushroom/mojs.svg?branch=master)](https://travis-ci.org/legomushroom/mojs) [![Coverage Status](https://coveralls.io/repos/legomushroom/mojs/badge.svg?branch=master)](https://coveralls.io/r/legomushroom/mojs?branch=master)

#### motion graphics toolbelt for the web

[![Sauce Test Status](https://saucelabs.com/browser-matrix/legomushroom.svg)](https://saucelabs.com/u/legomushroom)

## You can support the project [on Patreon](https://patreon.com/user?u=3219311&utm_medium=social&utm_source=twitter&utm_campaign=creatorshare) now!

## Website
[mojs.io](http://mojs.io/) [[repo](https://github.com/legomushroom/mojs-website)]

## Demos
  - [Motion Graphics for the Web](http://codepen.io/sol0mka/full/ogOYJj/)
  - [Bubble Layout](http://codepen.io/sol0mka/full/yNOage/)
  - [Sleepy Mole](http://codepen.io/sol0mka/full/OyzBXR)
  - [Animocons](http://tympanus.net/Development/Animocons/)
  - [Love or Hate Modal](http://codepen.io/sol0mka/full/812699ce32c9a7aeb70c9384b32a533a/)
  - [Mograph](http://codepen.io/sol0mka/full/39427561a8a0b15d7896480a7d96d3d1/)
  - [Word Reveal](http://codepen.io/sol0mka/full/c94452fb65dbf676b0ae8a12d4267473/)
  - [Physical Balls](http://codepen.io/sol0mka/full/7315f4364360ec87a6655d33782702fe/)
  - [Dust Trail](http://codepen.io/sol0mka/full/633e6aa52d40691cca2f2cda91650bae/)
  - [Bubble Modal](http://codepen.io/sol0mka/full/3c49de2d7d0ca3e92bf5db5bf7a2687d/)
  - [Bubbles](http://codepen.io/sol0mka/full/2ef10ed42ff535182c31cd1dbb81e453/)
  - [Blast](http://codepen.io/sol0mka/full/699cfc8716a13e0e1c15105af2b6fb95/) (click to see)
  - [Simple Burst](http://codepen.io/sol0mka/full/6caf96461207a5caa9226fbd2631569d/) (click to see)
  - [Dusty Burst](http://codepen.io/sol0mka/full/03e9d8f2fbf886aa1505c61c81d782a0/) (click to see)
  - [Twitter Fav](http://codepen.io/sol0mka/full/wWdRLk/) (click to see)
  - [Twitter Fav (stars)](http://codepen.io/sol0mka/full/PzmAym/) (click to see)
  - [Twitter Fav Firework](http://codepen.io/sol0mka/full/xOAKKA/) (click to see)
  - [Simple Ripple](http://codepen.io/sol0mka/full/XKdWJg/) (click to see)

## Tutorials
  - [Shape & Swirl](http://mojs.io/tutorials/shape/)
  - [Burst](http://mojs.io/tutorials/burst/)
  - [Path Easing](http://mojs.io/tutorials/easing/path-easing/)
  - [Icon Animations Powered by mo.js](http://tympanus.net/codrops/2016/02/23/icon-animations-powered-by-mo-js/)

## API
  - [Reference](https://github.com/legomushroom/mojs/blob/master/api/index.md)

## Tools
  - [MojsPlayer](https://github.com/legomushroom/mojs-player)

## Installation
### CDN
`<script src="//cdn.jsdelivr.net/mojs/latest/mo.min.js"></script>`  
### Bower
`bower install mojs`
### NPM
`npm install mo-js`

## Docs
Working hard on `APIs`, `tutorials` and `website`. Follow [@legomushroom](https://twitter.com/legomushroom) for updates. Star to show your interest.

## Target browsers
- Chrome 4+
- Firefox 4+
- Opera 11.5+
- Safari 4+
- IE 9+

## You can support the project [on Patreon](https://patreon.com/user?u=3219311&utm_medium=social&utm_source=twitter&utm_campaign=creatorshare) now!

## License

(The MIT License)

Copyright (c) Oleg Solomka [@LegoMushroom](https://twitter.com/legomushroom) [legomushroom@gmail.com](mailto:legomushroom@gmail.com)

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the 'Software'), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> mo-js-0.288.1.tgz: package/readme.md <==
# mo · js [![Build Status](https://travis-ci.org/legomushroom/mojs.svg?branch=master)](https://travis-ci.org/legomushroom/mojs) [![Coverage Status](https://coveralls.io/repos/legomushroom/mojs/badge.svg?branch=master)](https://coveralls.io/r/legomushroom/mojs?branch=master)

#### motion graphics toolbelt for the web
[mojs.io](http://mojs.io/)

[![Sauce Test Status](https://saucelabs.com/browser-matrix/legomushroom.svg)](https://saucelabs.com/u/legomushroom)

## Demos
  - [Motion Graphics for the Web](http://codepen.io/sol0mka/full/ogOYJj/)
  - [Bubble Layout](http://codepen.io/sol0mka/full/yNOage/)
  - [Sleepy Mole](http://codepen.io/sol0mka/full/OyzBXR)
  - [Animocons](http://tympanus.net/Development/Animocons/)
  - [Love or Hate Modal](http://codepen.io/sol0mka/full/812699ce32c9a7aeb70c9384b32a533a/)
  - [Mograph](http://codepen.io/sol0mka/full/39427561a8a0b15d7896480a7d96d3d1/)
  - [Word Reveal](http://codepen.io/sol0mka/full/c94452fb65dbf676b0ae8a12d4267473/)
  - [Physical Balls](http://codepen.io/sol0mka/full/7315f4364360ec87a6655d33782702fe/)
  - [Dust Trail](http://codepen.io/sol0mka/full/633e6aa52d40691cca2f2cda91650bae/)
  - [Bubble Modal](http://codepen.io/sol0mka/full/3c49de2d7d0ca3e92bf5db5bf7a2687d/)
  - [Bubbles](http://codepen.io/sol0mka/full/2ef10ed42ff535182c31cd1dbb81e453/)
  - [Blast](http://codepen.io/sol0mka/full/699cfc8716a13e0e1c15105af2b6fb95/) (click to see)
  - [Simple Burst](http://codepen.io/sol0mka/full/6caf96461207a5caa9226fbd2631569d/) (click to see)
  - [Dusty Burst](http://codepen.io/sol0mka/full/03e9d8f2fbf886aa1505c61c81d782a0/) (click to see)
  - [Twitter Fav](http://codepen.io/sol0mka/full/wWdRLk/) (click to see)
  - [Twitter Fav (stars)](http://codepen.io/sol0mka/full/PzmAym/) (click to see)
  - [Twitter Fav Firework](http://codepen.io/sol0mka/full/xOAKKA/) (click to see)
  - [Simple Ripple](http://codepen.io/sol0mka/full/XKdWJg/) (click to see)

## Tutorials
  - [Shape & Swirl](http://mojs.io/tutorials/shape/)
  - [Burst](http://mojs.io/tutorials/burst/)
  - [Path Easing](http://mojs.io/tutorials/easing/path-easing/)
  - [Icon Animations Powered by mo.js](http://tympanus.net/codrops/2016/02/23/icon-animations-powered-by-mo-js/)

## Docs
  - [Reference](https://github.com/legomushroom/mojs/blob/master/api/readme.md)

## Tools
  - [MojsPlayer](https://github.com/legomushroom/mojs-player)
  - [MojsCurveEditor](https://github.com/legomushroom/mojs-curve-editor)

## Installation

npm: `npm install mo-js`

cdn: `<script src="//cdn.jsdelivr.net/mojs/latest/mo.min.js"></script>`  

bower: `bower install mojs`

## Notes
Working hard on `APIs`, `tutorials` and `website`. Follow [@legomushroom](https://twitter.com/legomushroom) for updates. Star to show your interest.

## Target browsers
- Chrome 4+
- Firefox 4+
- Opera 11.5+
- Safari 4+
- IE 9+

## Thanks

Kudos to supporters on [Patreon](https://patreon.com/user?u=3219311&utm_medium=social&utm_source=twitter&utm_campaign=creatorshare):

- Zak Frisch

[full list of mojs patrons](./patrons.md)


## License

(The MIT License)

Copyright (c) Oleg Solomka [@LegoMushroom](https://twitter.com/legomushroom) [legomushroom@gmail.com](mailto:legomushroom@gmail.com)

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the 'Software'), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
